==> data_pipelines_elasticsearch-1.0.0.tar.gz: data_pipelines_elasticsearch/tests/src/Traits/ElasticsearchTestDestinationTrait.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\data_pipelines_elasticsearch\Traits;

use Drupal\data_pipelines\DatasetPipelinePluginManager;
use Drupal\data_pipelines\Destination\DatasetDestinationPluginInterface;
use Drupal\data_pipelines\Entity\Destination;
use Drupal\data_pipelines\Entity\DestinationInterface;
use Drupal\data_pipelines_elasticsearch\Plugin\DatasetDestination\ElasticSearchDestination;
use Elasticsearch\Client;
use Elasticsearch\Common\Exceptions\NoNodesAvailableException;
use Elasticsearch\Namespaces\IndicesNamespace;
use PHPUnit\Framework\MockObject\MockObject;
use Prophecy\Argument;
use Prophecy\Prophecy\ObjectProphecy;
use Psr\Log\LoggerInterface;

/**
 * Elasticsearch Destination Trait.
 */
trait ElasticsearchTestDestinationTrait {

  /**
   * The index prefix for all test cases.
   */
  const string INDEX_PREFIX = 'foo_';

  /**
   * The destination entity.
   *
   * @var \Drupal\data_pipelines\Entity\DestinationInterface
   */
  protected DestinationInterface $destination;

  /**
   * The destination plugin instance.
   *
   * @var \Drupal\data_pipelines\Destination\DatasetDestinationPluginInterface
   */
  protected DatasetDestinationPluginInterface $destinationPlugin;

  /**
   * The Elasticsearch client.
   *
   * @var \Elasticsearch\Client
   */
  protected Client $client;

  /**
   * Creates a test elasticsearch destination.
   *
   * @return \Drupal\data_pipelines\Entity\DestinationInterface
   *   The test destination.
   */
  protected function createElasticsearchDestination(array $values = []): DestinationInterface {
    $destinationId = $values['destinationId'] ?? $this->randomMachineName();
    $destination = Destination::create($values + [
      'id' => $destinationId,
      'label' => 'Test destination',
      'destination' => 'elasticsearch',
      'destinationSettings' => [
        'url' => getenv('ELASTICSEARCH_URL'),
        'username' => 'elastic',
        'password' => 'changeme',
        'prefix' => self::INDEX_PREFIX,
      ],
    ]);
    $destination->save();
    return $destination;
  }

  /**
   * Initializes Elastic client.
   *
   *   @covers \Drupal\data_pipelines_elasticsearch\Plugin\DatasetDestination\ElasticSearchDestination::getClient
   */
  protected function initializeElasticClient():void {
    $this->destination = $this->createElasticsearchDestination();
    $this->destinationPlugin = $this->destination->getDestinationPlugin();
    $this->client = $this->destinationPlugin->getClient();
    $this->assertInstanceOf(Client::class, $this->client);
    try {
      $this->client->ping();
    }
    catch (NoNodesAvailableException $exception) {
      $this->markTestSkipped('The test is skipped as no alive nodes found in cluster');
    }

  }

  /**
   * A method to mock the indexer required for testing indexing.
   *
   * @param \Drupal\data_pipelines\DatasetPipelinePluginManager $pipeline_manager
   *   The mocked pipeline manager.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   * @param \Elasticsearch\Client $client
   *   The mocked Elasticsearch client.
   *
   * @return \PHPUnit\Framework\MockObject\MockObject
   *   The mocked indexer.
   */
  protected function mockIndexer(DatasetPipelinePluginManager $pipeline_manager, LoggerInterface $logger, Client $client): MockObject {
    $configuration = [
      'prefix' => self::INDEX_PREFIX,
    ];
    $plugin_id = 'elasticsearch';
    $plugin_definition = [];
    $indexer = $this->getMockBuilder(ElasticSearchDestination::class)
      ->disableOriginalClone()
      ->onlyMethods(['getClient'])
      ->setConstructorArgs([$configuration, $plugin_id, $plugin_definition, $pipeline_manager, $logger])
      ->getMock();
    $indexer->method('getClient')->willReturn($client);
    return $indexer;
  }

  /**
   * Common place to prophesize indices object.
   *
   * Major versions of elasticsearch change the way this works, so moving to
   * common location.
   *
   * @param bool $index_exists
   *   The return value of ::exists() on Indices object.
   *
   * @return \Prophecy\Prophecy\ObjectProphecy
   *   The mocked Indices object.
   */
  protected function prophesizeIndices(bool $index_exists): ObjectProphecy {
    $indices = $this->prophesize(IndicesNamespace::class);
    $indices->exists(Argument::any())->willReturn($index_exists);
    return $indices;
  }

  /**
   * Assert that the index exists on the client.
   *
   * @param string $index_name
   *   The index name.
   */
  protected function assertIndexExists(string $index_name): void {
    $this->assertTrue($this->client->indices()->exists(['index' => self::INDEX_PREFIX . $index_name]), 'Index should exist.');
  }

  /**
   * Assert that the index does not exist on the client.
   *
   * @param string $index_name
   *   The index name.
   */
  protected function assertIndexNotExists(string $index_name): void {
    $this->assertFalse($this->client->indices()->exists(['index' => self::INDEX_PREFIX . $index_name]), 'Index should not exist.');
  }

}

==> data_pipelines_elasticsearch-2.0.0.tar.gz: data_pipelines_elasticsearch/tests/src/Traits/ElasticsearchTestDestinationTrait.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\data_pipelines_elasticsearch\Traits;

use Drupal\data_pipelines\DatasetPipelinePluginManager;
use Drupal\data_pipelines\Destination\DatasetDestinationPluginInterface;
use Drupal\data_pipelines\Entity\Destination;
use Drupal\data_pipelines\Entity\DestinationInterface;
use Drupal\data_pipelines_elasticsearch\Plugin\DatasetDestination\ElasticSearchDestination;
use Elastic\Elasticsearch\Client;
use Elastic\Elasticsearch\Endpoints\Indices;
use Elastic\Elasticsearch\Response\Elasticsearch;
use Elastic\Transport\Exception\NoNodeAvailableException;
use PHPUnit\Framework\MockObject\MockObject;
use Prophecy\Argument;
use Prophecy\Prophecy\ObjectProphecy;
use Psr\Log\LoggerInterface;

/**
 * Elasticsearch Destination Trait.
 */
trait ElasticsearchTestDestinationTrait {

  /**
   * The index prefix for all test cases.
   */
  const string INDEX_PREFIX = 'foo_';

  /**
   * The destination entity.
   *
   * @var \Drupal\data_pipelines\Entity\DestinationInterface
   */
  protected DestinationInterface $destination;

  /**
   * The destination plugin instance.
   *
   * @var \Drupal\data_pipelines\Destination\DatasetDestinationPluginInterface
   */
  protected DatasetDestinationPluginInterface $destinationPlugin;

  /**
   * The Elasticsearch client.
   *
   * @var \Elastic\Elasticsearch\Client
   */
  protected Client $client;

  /**
   * Creates a test elasticsearch destination.
   *
   * @return \Drupal\data_pipelines\Entity\DestinationInterface
   *   The test destination.
   */
  protected function createElasticsearchDestination(array $values = []): DestinationInterface {
    $destinationId = $values['destinationId'] ?? $this->randomMachineName();
    $destination = Destination::create($values + [
      'id' => $destinationId,
      'label' => 'Test destination',
      'destination' => 'elasticsearch',
      'destinationSettings' => [
        'url' => getenv('ELASTICSEARCH_URL'),
        'username' => 'elastic',
        'password' => 'changeme',
        'prefix' => self::INDEX_PREFIX,
      ],
    ]);
    $destination->save();
    return $destination;
  }

  /**
   * Initializes Elastic client.
   *
   *   @covers \Drupal\data_pipelines_elasticsearch\Plugin\DatasetDestination\ElasticSearchDestination::getClient
   */
  protected function initializeElasticClient():void {
    $this->destination = $this->createElasticsearchDestination();
    $this->destinationPlugin = $this->destination->getDestinationPlugin();
    $this->client = $this->destinationPlugin->getClient();
    $this->assertInstanceOf(Client::class, $this->client);
    try {
      $this->client->ping();
    }
    catch (NoNodeAvailableException) {
      $this->markTestSkipped('The test is skipped as no alive nodes found in cluster');
    }

  }

  /**
   * A method to mock the indexer required for testing indexing.
   *
   * @param \Drupal\data_pipelines\DatasetPipelinePluginManager $pipeline_manager
   *   The mocked pipeline manager.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   * @param \Elastic\Elasticsearch\Client $client
   *   The mocked Elasticsearch client.
   *
   * @return \PHPUnit\Framework\MockObject\MockObject
   *   The mocked indexer.
   */
  protected function mockIndexer(DatasetPipelinePluginManager $pipeline_manager, LoggerInterface $logger, Client $client): MockObject {
    $configuration = [
      'prefix' => self::INDEX_PREFIX,
    ];
    $plugin_id = 'elasticsearch';
    $plugin_definition = [];
    $indexer = $this->getMockBuilder(ElasticSearchDestination::class)
      ->disableOriginalClone()
      ->onlyMethods(['getClient'])
      ->setConstructorArgs([$configuration, $plugin_id, $plugin_definition, $pipeline_manager, $logger])
      ->getMock();
    $indexer->method('getClient')->willReturn($client);
    return $indexer;
  }

  /**
   * Common place to prophesize indices object.
   *
   * Major versions of elasticsearch change the way this works, so moving to
   * common location.
   *
   * @param bool $index_exists
   *   The return value of ::exists() on Indices object.
   *
   * @return \Prophecy\Prophecy\ObjectProphecy
   *   The mocked Indices object.
   */
  protected function prophesizeIndices(bool $index_exists): ObjectProphecy {
    $indices = $this->prophesize(Indices::class);
    $indices_exists_result = $this->prophesize(Elasticsearch::class);
    $indices_exists_result->asBool()->willReturn($index_exists);
    $indices->exists(Argument::any())->willReturn($indices_exists_result->reveal());
    return $indices;
  }

  /**
   * Assert that the index exists on the client.
   *
   * @param string $index_name
   *   The index name.
   */
  protected function assertIndexExists(string $index_name): void {
    $this->assertTrue($this->client->indices()->exists(['index' => self::INDEX_PREFIX . $index_name])->asBool(), 'Index should exist.');
  }

  /**
   * Assert that the index does not exist on the client.
   *
   * @param string $index_name
   *   The index name.
   */
  protected function assertIndexNotExists(string $index_name): void {
    $this->assertFalse($this->client->indices()->exists(['index' => self::INDEX_PREFIX . $index_name])->asBool(), 'Index should not exist.');
  }

}
